@@ -183,7 +183,7 @@ def make_zip(filename, source_root):
     with open(zipfile_name, 'wb') as f:
         zip_file = zipfile.ZipFile(f, 'w', zipfile.ZIP_DEFLATED)
         with contextlib.closing(zip_file) as zf:
-            for root, dirs, files in os.walk(source_root):
+            for root, dirs, files in os.walk(source_root, followlinks=True):
                 for filename in files:
                     full_path = os.path.join(root, filename)
                     relative_path = os.path.relpath(
@@ -344,6 +344,22 @@ class AppSyncResolverResponseTemplateResource(Resource):
     PACKAGE_NULL_PROPERTY = False
 
 
+class AppSyncFunctionConfigurationRequestTemplateResource(Resource):
+    RESOURCE_TYPE = "AWS::AppSync::FunctionConfiguration"
+    PROPERTY_NAME = "RequestMappingTemplateS3Location"
+    # Don't package the directory if RequestMappingTemplateS3Location is omitted.
+    # Necessary to support RequestMappingTemplate
+    PACKAGE_NULL_PROPERTY = False
+
+
+class AppSyncFunctionConfigurationResponseTemplateResource(Resource):
+    RESOURCE_TYPE = "AWS::AppSync::FunctionConfiguration"
+    PROPERTY_NAME = "ResponseMappingTemplateS3Location"
+    # Don't package the directory if ResponseMappingTemplateS3Location is omitted.
+    # Necessary to support ResponseMappingTemplate
+    PACKAGE_NULL_PROPERTY = False
+
+
 class LambdaFunctionResource(ResourceWithS3UrlDict):
     RESOURCE_TYPE = "AWS::Lambda::Function"
     PROPERTY_NAME = "Code"
@@ -385,6 +401,18 @@ class ServerlessLayerVersionResource(Resource):
     FORCE_ZIP = True
 
 
+class ServerlessRepoApplicationReadme(Resource):
+    RESOURCE_TYPE = "AWS::ServerlessRepo::Application"
+    PROPERTY_NAME = "ReadmeUrl"
+    PACKAGE_NULL_PROPERTY = False
+
+
+class ServerlessRepoApplicationLicense(Resource):
+    RESOURCE_TYPE = "AWS::ServerlessRepo::Application"
+    PROPERTY_NAME = "LicenseUrl"
+    PACKAGE_NULL_PROPERTY = False
+
+
 class CloudFormationStackResource(Resource):
     """
     Represents CloudFormation::Stack resource that can refer to a nested
@@ -444,12 +472,14 @@ class ServerlessApplicationResource(CloudFormationStackResource):
     PROPERTY_NAME = "Location"
 
 
-EXPORT_LIST = [
+RESOURCES_EXPORT_LIST = [
     ServerlessFunctionResource,
     ServerlessApiResource,
     GraphQLSchemaResource,
     AppSyncResolverRequestTemplateResource,
     AppSyncResolverResponseTemplateResource,
+    AppSyncFunctionConfigurationRequestTemplateResource,
+    AppSyncFunctionConfigurationResponseTemplateResource,
     ApiGatewayRestApiResource,
     LambdaFunctionResource,
     ElasticBeanstalkApplicationVersion,
@@ -459,6 +489,12 @@ EXPORT_LIST = [
     LambdaLayerVersionResource,
 ]
 
+METADATA_EXPORT_LIST = [
+    ServerlessRepoApplicationReadme,
+    ServerlessRepoApplicationLicense
+]
+
+
 def include_transform_export_handler(template_dict, uploader):
     if template_dict.get("Name", None) != "AWS::Include":
         return template_dict
@@ -467,6 +503,7 @@ def include_transform_export_handler(template_dict, uploader):
         template_dict["Parameters"]["Location"] = uploader.upload_with_dedup(include_location)
     return template_dict
 
+
 GLOBAL_EXPORT_DICT = {
     "Fn::Transform": include_transform_export_handler
 }
@@ -478,7 +515,8 @@ class Template(object):
     """
 
     def __init__(self, template_path, parent_dir, uploader,
-                 resources_to_export=EXPORT_LIST):
+                 resources_to_export=RESOURCES_EXPORT_LIST,
+                 metadata_to_export=METADATA_EXPORT_LIST):
         """
         Reads the template and makes it ready for export
         """
@@ -497,6 +535,7 @@ class Template(object):
         self.template_dict = yaml_parse(template_str)
         self.template_dir = template_dir
         self.resources_to_export = resources_to_export
+        self.metadata_to_export = metadata_to_export
         self.uploader = uploader
 
     def export_global_artifacts(self, template_dict):
@@ -517,6 +556,26 @@ class Template(object):
                         self.export_global_artifacts(item)
         return template_dict
 
+    def export_metadata(self, template_dict):
+        """
+        Exports the local artifacts referenced by the metadata section in
+        the given template to an s3 bucket.
+
+        :return: The template with references to artifacts that have been
+        exported to s3.
+        """
+        if "Metadata" not in template_dict:
+            return template_dict
+
+        for metadata_type, metadata_dict in template_dict["Metadata"].items():
+            for exporter_class in self.metadata_to_export:
+                if exporter_class.RESOURCE_TYPE != metadata_type:
+                    continue
+
+                exporter = exporter_class(self.uploader)
+                exporter.export(metadata_type, metadata_dict, self.template_dir)
+
+        return template_dict
 
     def export(self):
         """
@@ -526,6 +585,8 @@ class Template(object):
         :return: The template with references to artifacts that have been
         exported to s3.
         """
+        self.template_dict = self.export_metadata(self.template_dict)
+
         if "Resources" not in self.template_dict:
             return self.template_dict
 
